==> ejc-analysis-api-3.0.0-20230712.091259-67-sources.jar: com/ejianc/business/analysis/vo/CostVO.java <==
package com.ejianc.business.analysis.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 薪酬及三公费用占现场经费比例分析
 * 
 * @author generator
 * 
 */
public class CostVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long orgId; // 所属组织id
    private String orgCode; // 所属组织编码
    private String orgName; // 所属组织名称
    private Long projectDepartmentId; // 项目部id
    private Long twoOrgId; // 二级组织id
    private String twoOrgCode; // 二级组织编码
    private String twoOrgName; // 二级组织名称
    private Long projectId; // 项目id
    private String projectCode; // 项目编码
    private String projectName; // 项目名称
    private Integer projectStatus; // 项目状态
    private String reportingMonth; // 报表日期
    private BigDecimal xcMny; // 薪酬（五险一金）
    private BigDecimal bgMny; // 办公费用
    private BigDecimal clMny; // 差旅费用
    private BigDecimal zdMny; // 招待费用
    private BigDecimal qtMny; // 其他
    private String memo; // 备注
    private Date projectCreateTime; // 项目创建日期
    private Date costAnalysisCreateTime; // 月度分析报告创建时间
    private Integer orgStatusOrder; // 二级组织排序
    private BigDecimal mny; // 合计
    private BigDecimal costMny; // 各种费用
    private String code; // 费用编码
    private BigDecimal xcRate; // 薪酬（五险一金）占比
    private BigDecimal bgRate; // 办公费用占比
    private BigDecimal clRate; // 差旅费用占比
    private BigDecimal zdRate; // 招待费用占比
    private BigDecimal qtRate; // 其他占比
    private String number; // 序号
    private Integer projectStatusOrder; // 项目状态排序
    private String projectStatusName;

    public String getProjectStatusName() {
        return projectStatusName;
    }

    public void setProjectStatusName(String projectStatusName) {
        this.projectStatusName = projectStatusName;
    }

    public Integer getProjectStatusOrder() {
        return projectStatusOrder;
    }

    public void setProjectStatusOrder(Integer projectStatusOrder) {
        this.projectStatusOrder = projectStatusOrder;
    }

    public String getNumber() {
        return number;
    }

    public void setNumber(String number) {
        this.number = number;
    }

    public BigDecimal getXcRate() {
        return xcRate;
    }

    public void setXcRate(BigDecimal xcRate) {
        this.xcRate = xcRate;
    }

    public BigDecimal getBgRate() {
        return bgRate;
    }

    public void setBgRate(BigDecimal bgRate) {
        this.bgRate = bgRate;
    }

    public BigDecimal getClRate() {
        return clRate;
    }

    public void setClRate(BigDecimal clRate) {
        this.clRate = clRate;
    }

    public BigDecimal getZdRate() {
        return zdRate;
    }

    public void setZdRate(BigDecimal zdRate) {
        this.zdRate = zdRate;
    }

    public BigDecimal getQtRate() {
        return qtRate;
    }

    public void setQtRate(BigDecimal qtRate) {
        this.qtRate = qtRate;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public BigDecimal getCostMny() {
        return costMny;
    }

    public void setCostMny(BigDecimal costMny) {
        this.costMny = costMny;
    }

    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    public Long getTwoOrgId() {
        return twoOrgId;
    }

    public void setTwoOrgId(Long twoOrgId) {
        this.twoOrgId = twoOrgId;
    }
    public String getTwoOrgCode() {
        return twoOrgCode;
    }

    public void setTwoOrgCode(String twoOrgCode) {
        this.twoOrgCode = twoOrgCode;
    }
    public String getTwoOrgName() {
        return twoOrgName;
    }

    public void setTwoOrgName(String twoOrgName) {
        this.twoOrgName = twoOrgName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Integer getProjectStatus() {
        return projectStatus;
    }

    public void setProjectStatus(Integer projectStatus) {
        this.projectStatus = projectStatus;
    }
    public String getReportingMonth() {
        return reportingMonth;
    }

    public void setReportingMonth(String reportingMonth) {
        this.reportingMonth = reportingMonth;
    }
    public BigDecimal getXcMny() {
        return xcMny;
    }

    public void setXcMny(BigDecimal xcMny) {
        this.xcMny = xcMny;
    }
    public BigDecimal getBgMny() {
        return bgMny;
    }

    public void setBgMny(BigDecimal bgMny) {
        this.bgMny = bgMny;
    }
    public BigDecimal getClMny() {
        return clMny;
    }

    public void setClMny(BigDecimal clMny) {
        this.clMny = clMny;
    }
    public BigDecimal getZdMny() {
        return zdMny;
    }

    public void setZdMny(BigDecimal zdMny) {
        this.zdMny = zdMny;
    }
    public BigDecimal getQtMny() {
        return qtMny;
    }

    public void setQtMny(BigDecimal qtMny) {
        this.qtMny = qtMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Date getProjectCreateTime() {
        return projectCreateTime;
    }

    public void setProjectCreateTime(Date projectCreateTime) {
        this.projectCreateTime = projectCreateTime;
    }
    public Date getCostAnalysisCreateTime() {
        return costAnalysisCreateTime;
    }

    public void setCostAnalysisCreateTime(Date costAnalysisCreateTime) {
        this.costAnalysisCreateTime = costAnalysisCreateTime;
    }
    public Integer getOrgStatusOrder() {
        return orgStatusOrder;
    }

    public void setOrgStatusOrder(Integer orgStatusOrder) {
        this.orgStatusOrder = orgStatusOrder;
    }
    
}

==> ejc-analysis-api-3.0.0-20241018.063503-263-sources.jar: com/ejianc/business/analysis/vo/CostVO.java <==
package com.ejianc.business.analysis.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 薪酬及三公费用占现场经费比例分析
 * 
 * @author generator
 * 
 */
public class CostVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long orgId; // 所属组织id
    private String orgCode; // 所属组织编码
    private String orgName; // 所属组织名称
    private Long projectDepartmentId; // 项目部id
    private Long twoOrgId; // 二级组织id
    private String twoOrgCode; // 二级组织编码
    private String twoOrgName; // 二级组织名称
    private Long projectId; // 项目id
    private String projectCode; // 项目编码
    private String projectName; // 项目名称
    private Integer projectStatus; // 项目状态
    private String reportingMonth; // 报表日期
    private BigDecimal xcMny; // 薪酬（五险一金）
    private BigDecimal bgMny; // 办公费用
    private BigDecimal clMny; // 差旅费用
    private BigDecimal zdMny; // 招待费用
    private BigDecimal qtMny; // 其他
    private String memo; // 备注
    private Date projectCreateTime; // 项目创建日期
    private Date costAnalysisCreateTime; // 月度分析报告创建时间
    private Integer orgStatusOrder; // 二级组织排序
    private BigDecimal mny; // 合计
    private BigDecimal costMny; // 各种费用
    private String code; // 费用编码
    private BigDecimal xcRate; // 薪酬（五险一金）占比
    private BigDecimal bgRate; // 办公费用占比
    private BigDecimal clRate; // 差旅费用占比
    private BigDecimal zdRate; // 招待费用占比
    private BigDecimal qtRate; // 其他占比
    private String number; // 序号
    private Integer projectStatusOrder; // 项目状态排序
    private String projectStatusName;
    private String shortName;//组织简称
    public String getShortName() {
        return shortName;
    }

    public void setShortName(String shortName) {
        this.shortName = shortName;
    }
    public String getProjectStatusName() {
        return projectStatusName;
    }

    public void setProjectStatusName(String projectStatusName) {
        this.projectStatusName = projectStatusName;
    }

    public Integer getProjectStatusOrder() {
        return projectStatusOrder;
    }

    public void setProjectStatusOrder(Integer projectStatusOrder) {
        this.projectStatusOrder = projectStatusOrder;
    }

    public String getNumber() {
        return number;
    }

    public void setNumber(String number) {
        this.number = number;
    }

    public BigDecimal getXcRate() {
        return xcRate;
    }

    public void setXcRate(BigDecimal xcRate) {
        this.xcRate = xcRate;
    }

    public BigDecimal getBgRate() {
        return bgRate;
    }

    public void setBgRate(BigDecimal bgRate) {
        this.bgRate = bgRate;
    }

    public BigDecimal getClRate() {
        return clRate;
    }

    public void setClRate(BigDecimal clRate) {
        this.clRate = clRate;
    }

    public BigDecimal getZdRate() {
        return zdRate;
    }

    public void setZdRate(BigDecimal zdRate) {
        this.zdRate = zdRate;
    }

    public BigDecimal getQtRate() {
        return qtRate;
    }

    public void setQtRate(BigDecimal qtRate) {
        this.qtRate = qtRate;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public BigDecimal getCostMny() {
        return costMny;
    }

    public void setCostMny(BigDecimal costMny) {
        this.costMny = costMny;
    }

    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    public Long getTwoOrgId() {
        return twoOrgId;
    }

    public void setTwoOrgId(Long twoOrgId) {
        this.twoOrgId = twoOrgId;
    }
    public String getTwoOrgCode() {
        return twoOrgCode;
    }

    public void setTwoOrgCode(String twoOrgCode) {
        this.twoOrgCode = twoOrgCode;
    }
    public String getTwoOrgName() {
        return twoOrgName;
    }

    public void setTwoOrgName(String twoOrgName) {
        this.twoOrgName = twoOrgName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Integer getProjectStatus() {
        return projectStatus;
    }

    public void setProjectStatus(Integer projectStatus) {
        this.projectStatus = projectStatus;
    }
    public String getReportingMonth() {
        return reportingMonth;
    }

    public void setReportingMonth(String reportingMonth) {
        this.reportingMonth = reportingMonth;
    }
    public BigDecimal getXcMny() {
        return xcMny;
    }

    public void setXcMny(BigDecimal xcMny) {
        this.xcMny = xcMny;
    }
    public BigDecimal getBgMny() {
        return bgMny;
    }

    public void setBgMny(BigDecimal bgMny) {
        this.bgMny = bgMny;
    }
    public BigDecimal getClMny() {
        return clMny;
    }

    public void setClMny(BigDecimal clMny) {
        this.clMny = clMny;
    }
    public BigDecimal getZdMny() {
        return zdMny;
    }

    public void setZdMny(BigDecimal zdMny) {
        this.zdMny = zdMny;
    }
    public BigDecimal getQtMny() {
        return qtMny;
    }

    public void setQtMny(BigDecimal qtMny) {
        this.qtMny = qtMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Date getProjectCreateTime() {
        return projectCreateTime;
    }

    public void setProjectCreateTime(Date projectCreateTime) {
        this.projectCreateTime = projectCreateTime;
    }
    public Date getCostAnalysisCreateTime() {
        return costAnalysisCreateTime;
    }

    public void setCostAnalysisCreateTime(Date costAnalysisCreateTime) {
        this.costAnalysisCreateTime = costAnalysisCreateTime;
    }
    public Integer getOrgStatusOrder() {
        return orgStatusOrder;
    }

    public void setOrgStatusOrder(Integer orgStatusOrder) {
        this.orgStatusOrder = orgStatusOrder;
    }
    
}
